@@ -1,13 +1,12 @@
 import os
-import shutil
-from importlib import resources
 from pathlib import Path
 
 import appdirs
 
 from .. import __appname__
+from .app_resources import get_resource_file
 
-DEFAULT_CONFIG = resources.path("baca.resources", "config.ini")
+DEFAULT_CONFIG = get_resource_file("config.ini")
 
 
 def retrieve_user_cache_dbfile() -> Path:
@@ -25,6 +24,8 @@ def retrieve_user_config_file() -> Path:
 
     configfile = configdir / "config.ini"
     if not os.path.isfile(configfile):
-        shutil.copyfile(str(DEFAULT_CONFIG), str(configfile))
+        # shutil.copyfile(str(DEFAULT_CONFIG), str(configfile))
+        with open(DEFAULT_CONFIG, "r", encoding="utf-8") as src, open(configfile, "w", encoding="utf-8") as dest:
+            dest.write(src.read())
 
     return configfile
